@@ -8,7 +8,9 @@ and use at your heart's content!
 @author: David Losada Carballo <david@tuxpiper.com>
 '''
 
-from cloudcast.elements import Parameter, Mapping, Resource, Output, EC2Instance, EC2LaunchConfiguration
+from cloudcast.elements import \
+	Parameter, Mapping, Resource, Output, EC2Instance, EC2LaunchConfiguration, \
+	get_ref_name
 
 class AWS:
     from cloudcast.elements import CfnSimpleExpr
